# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.131
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from helix_platform_api_public_client_legacy.models.aggregated_nominations import AggregatedNominations  # noqa: E501

class TestAggregatedNominations(unittest.TestCase):
    """AggregatedNominations unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AggregatedNominations:
        """Test AggregatedNominations
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AggregatedNominations`
        """
        model = AggregatedNominations()  # noqa: E501
        if include_optional:
            return AggregatedNominations(
                mpn = helix_platform_api_public_client_legacy.models.aggregated_nominations_values.AggregatedNominationsValues(
                    mtu_size = 'MTU_15_MINS', 
                    mtus = [
                        helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus.AggregatedNominationsValues_mtus(
                            mtu = '2022-01-04T10:00Z', 
                            values = [
                                helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus_values.AggregatedNominationsValues_mtus_values(
                                    direction = 'GB_FR', 
                                    value = 56, )
                                ], 
                            netted_nominations = helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus_netted_nominations.AggregatedNominationsValues_mtus_nettedNominations(
                                direction = 'GB_FR', 
                                flow = 56, ), )
                        ], ),
                gb = helix_platform_api_public_client_legacy.models.aggregated_nominations_values.AggregatedNominationsValues(
                    mtu_size = 'MTU_15_MINS', 
                    mtus = [
                        helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus.AggregatedNominationsValues_mtus(
                            mtu = '2022-01-04T10:00Z', 
                            values = [
                                helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus_values.AggregatedNominationsValues_mtus_values(
                                    direction = 'GB_FR', 
                                    value = 56, )
                                ], 
                            netted_nominations = helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus_netted_nominations.AggregatedNominationsValues_mtus_nettedNominations(
                                direction = 'GB_FR', 
                                flow = 56, ), )
                        ], ),
                fr = helix_platform_api_public_client_legacy.models.aggregated_nominations_values.AggregatedNominationsValues(
                    mtu_size = 'MTU_15_MINS', 
                    mtus = [
                        helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus.AggregatedNominationsValues_mtus(
                            mtu = '2022-01-04T10:00Z', 
                            values = [
                                helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus_values.AggregatedNominationsValues_mtus_values(
                                    direction = 'GB_FR', 
                                    value = 56, )
                                ], 
                            netted_nominations = helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus_netted_nominations.AggregatedNominationsValues_mtus_nettedNominations(
                                direction = 'GB_FR', 
                                flow = 56, ), )
                        ], )
            )
        else:
            return AggregatedNominations(
                mpn = helix_platform_api_public_client_legacy.models.aggregated_nominations_values.AggregatedNominationsValues(
                    mtu_size = 'MTU_15_MINS', 
                    mtus = [
                        helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus.AggregatedNominationsValues_mtus(
                            mtu = '2022-01-04T10:00Z', 
                            values = [
                                helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus_values.AggregatedNominationsValues_mtus_values(
                                    direction = 'GB_FR', 
                                    value = 56, )
                                ], 
                            netted_nominations = helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus_netted_nominations.AggregatedNominationsValues_mtus_nettedNominations(
                                direction = 'GB_FR', 
                                flow = 56, ), )
                        ], ),
                gb = helix_platform_api_public_client_legacy.models.aggregated_nominations_values.AggregatedNominationsValues(
                    mtu_size = 'MTU_15_MINS', 
                    mtus = [
                        helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus.AggregatedNominationsValues_mtus(
                            mtu = '2022-01-04T10:00Z', 
                            values = [
                                helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus_values.AggregatedNominationsValues_mtus_values(
                                    direction = 'GB_FR', 
                                    value = 56, )
                                ], 
                            netted_nominations = helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus_netted_nominations.AggregatedNominationsValues_mtus_nettedNominations(
                                direction = 'GB_FR', 
                                flow = 56, ), )
                        ], ),
                fr = helix_platform_api_public_client_legacy.models.aggregated_nominations_values.AggregatedNominationsValues(
                    mtu_size = 'MTU_15_MINS', 
                    mtus = [
                        helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus.AggregatedNominationsValues_mtus(
                            mtu = '2022-01-04T10:00Z', 
                            values = [
                                helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus_values.AggregatedNominationsValues_mtus_values(
                                    direction = 'GB_FR', 
                                    value = 56, )
                                ], 
                            netted_nominations = helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus_netted_nominations.AggregatedNominationsValues_mtus_nettedNominations(
                                direction = 'GB_FR', 
                                flow = 56, ), )
                        ], ),
        )
        """

    def testAggregatedNominations(self):
        """Test AggregatedNominations"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.131
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import date
from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, conlist
from helix_platform_api_public_client_legacy.models.border_direction import BorderDirection

class ParticipantDashboardNominationOptionsTimescale(BaseModel):
    """
    ParticipantDashboardNominationOptionsTimescale
    """
    delivery_days: conlist(date) = Field(default=..., alias="deliveryDays")
    available: StrictBool = Field(...)
    tr_directions: Optional[conlist(BorderDirection)] = Field(default=None, alias="trDirections")
    __properties = ["deliveryDays", "available", "trDirections"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ParticipantDashboardNominationOptionsTimescale:
        """Create an instance of ParticipantDashboardNominationOptionsTimescale from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ParticipantDashboardNominationOptionsTimescale:
        """Create an instance of ParticipantDashboardNominationOptionsTimescale from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ParticipantDashboardNominationOptionsTimescale.parse_obj(obj)

        _obj = ParticipantDashboardNominationOptionsTimescale.parse_obj({
            "delivery_days": obj.get("deliveryDays"),
            "available": obj.get("available"),
            "tr_directions": obj.get("trDirections")
        })
        return _obj





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.131
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from helix_platform_api_public_client_legacy.models.default_nomination_batch import DefaultNominationBatch  # noqa: E501

class TestDefaultNominationBatch(unittest.TestCase):
    """DefaultNominationBatch unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DefaultNominationBatch:
        """Test DefaultNominationBatch
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DefaultNominationBatch`
        """
        model = DefaultNominationBatch()  # noqa: E501
        if include_optional:
            return DefaultNominationBatch(
                entries = [
                    helix_platform_api_public_client_legacy.models.default_nomination.DefaultNomination(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        timescale = 'LONG_TERM', 
                        delivery_period_start = 'Tue Jan 04 00:00:00 UTC 2022', 
                        delivery_period_end = 'Tue Jan 04 00:00:00 UTC 2022', 
                        border_direction = 'GB_FR', 
                        status = 'ACTIVE', )
                    ],
                total_count = 0
            )
        else:
            return DefaultNominationBatch(
                entries = [
                    helix_platform_api_public_client_legacy.models.default_nomination.DefaultNomination(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        timescale = 'LONG_TERM', 
                        delivery_period_start = 'Tue Jan 04 00:00:00 UTC 2022', 
                        delivery_period_end = 'Tue Jan 04 00:00:00 UTC 2022', 
                        border_direction = 'GB_FR', 
                        status = 'ACTIVE', )
                    ],
                total_count = 0,
        )
        """

    def testDefaultNominationBatch(self):
        """Test DefaultNominationBatch"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
